@@ -12,7 +12,7 @@ from .client import AsyncClient
 from .exceptions import BinanceWebsocketUnableToConnect
 from .enums import FuturesType
 
-DEFAULT_USER_TIMEOUT = 30 * 60  # 30 minutes
+KEEPALIVE_TIMEOUT = 5 * 60  # 5 minutes
 
 
 class WSListenerState(Enum):
@@ -86,7 +86,7 @@ class ReconnectingWebsocket:
         try:
             return json.loads(evt)
         except ValueError:
-            self._log.debug('error parsing evt json:{}'.format(evt))
+            self._log.debug(f'error parsing evt json:{evt}')
             return None
 
     async def recv(self):
@@ -174,7 +174,7 @@ class KeepAliveWebsocket(ReconnectingWebsocket):
         super().__init__(loop=loop, path=None, url=url, prefix=prefix, is_binary=is_binary, exit_coro=exit_coro)
         self._keepalive_type = keepalive_type
         self._client = client
-        self._user_timeout = user_timeout or DEFAULT_USER_TIMEOUT
+        self._user_timeout = user_timeout or KEEPALIVE_TIMEOUT
         self._timer = None
 
     async def __aexit__(self, *args, **kwargs):
@@ -195,7 +195,8 @@ class KeepAliveWebsocket(ReconnectingWebsocket):
     def _start_socket_timer(self):
         self._timer = self._loop.call_later(
             self._user_timeout,
-            self._keepalive_socket
+            asyncio.create_task,
+            self._keepalive_socket()
         )
 
     async def _get_listen_key(self):
@@ -216,9 +217,11 @@ class KeepAliveWebsocket(ReconnectingWebsocket):
         listen_key = await self._get_listen_key()
 
         if listen_key != self._path:
+            print("listen key changed: reconnect")
             self._path = listen_key
             await self._reconnect()
         else:
+            print("listen key same: keepalive")
             if self._keepalive_type == 'user':
                 await self._client.stream_keepalive(self._path)
             elif self._keepalive_type == 'margin':  # cross-margin
@@ -248,7 +251,7 @@ class BinanceSocketManager:
     WEBSOCKET_DEPTH_10 = '10'
     WEBSOCKET_DEPTH_20 = '20'
 
-    def __init__(self, client: AsyncClient, loop=None, user_timeout=DEFAULT_USER_TIMEOUT):
+    def __init__(self, client: AsyncClient, loop=None, user_timeout=KEEPALIVE_TIMEOUT):
         """Initialise the BinanceSocketManager
 
         :param client: Binance API client
@@ -392,10 +395,10 @@ class BinanceSocketManager:
         """
         socket_name = symbol.lower() + '@depth'
         if depth and depth != '1':
-            socket_name = '{}{}'.format(socket_name, depth)
+            socket_name = f'{socket_name}{depth}'
         if interval:
             if interval in [0, 100]:
-                socket_name = '{}@{}ms'.format(socket_name, interval)
+                socket_name = f'{socket_name}@{interval}ms'
             else:
                 raise ValueError("Websocket interval value not allowed. Allowed values are [0, 100]")
         return self._get_socket(socket_name)
@@ -441,7 +444,7 @@ class BinanceSocketManager:
                     }
             }
         """
-        path = '{}@kline_{}'.format(symbol.lower(), interval)
+        path = f'{symbol.lower()}@kline_{interval}'
         return self._get_socket(path)
 
     def miniticker_socket(self, update_time: int = 1000):
@@ -474,7 +477,7 @@ class BinanceSocketManager:
             ]
         """
 
-        return self._get_socket('!miniTicker@arr@{}ms'.format(update_time))
+        return self._get_socket(f'!miniTicker@arr@{update_time}ms')
 
     def trade_socket(self, symbol: str):
         """Start a websocket for symbol trade data
@@ -840,7 +843,7 @@ class BinanceSocketManager:
         Message Format - see Binance API docs for all types
 
         """
-        path = 'streams={}'.format('/'.join(streams))
+        path = f'streams={"/".join(streams)}'
         return self._get_socket(path, prefix='stream?')
 
     def options_multiplex_socket(self, streams: List[str]):
@@ -861,7 +864,8 @@ class BinanceSocketManager:
         Message Format - see Binance API docs for all types
 
         """
-        stream_path = 'streams={}'.format('/'.join([s.lower() for s in streams]))
+        stream_name = '/'.join([s.lower() for s in streams])
+        stream_path = f'streams={stream_name}'
         return self._get_options_socket(stream_path, prefix='stream?')
 
     def futures_multiplex_socket(self, streams: List[str], futures_type: FuturesType = FuturesType.USD_M):
@@ -882,7 +886,7 @@ class BinanceSocketManager:
         Message Format - see Binance API docs for all types
 
         """
-        path = 'streams={}'.format('/'.join(streams))
+        path = f'streams={"/".join(streams)}'
         return self._get_futures_socket(path, prefix='stream?', futures_type=futures_type)
 
     def user_socket(self):
